%define major		0
%define libname		%mklibname i2c %{major}
%define develname	%mklibname i2c -d

Name:		i2c-tools
Version:	4.4
Release:	%mkrel 3
Summary:	Heterogeneous set of I2C tools for Linux
Group:		System/Kernel and hardware
License:	GPLv2+
URL:		https://i2c.wiki.kernel.org/index.php/I2C_Tools
Source0:	https://git.kernel.org/pub/scm/utils/i2c-tools/i2c-tools.git/snapshot/%{name}-%{version}.tar.gz
Requires:	udev

Provides:	%{name}-eepromer = %{version}-%{release}
Obsoletes:	i2c-tools-eepromer < 4.3.2

%description
This package contains a heterogeneous set of I2C tools for Linux: a bus
probing tool, a chip dumper, register-level access helpers, EEPROM
decoding scripts, and more.

#------------------------------------------------

%package -n python3-smbus
Summary:	Python 3 module for SMBus access via I2C
Group:		System/Kernel and hardware
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-setuptools
%{?python_provide:%python_provide python3-smbus}
Requires:	python3

%description -n python3-smbus
This Python 3 module allows SMBus access through the I2C /dev interface
on Linux hosts. The host kernel must have I2C support, I2C device
interface support, and a bus adapter driver.

#------------------------------------------------

%package -n	%{libname}
Summary:	I2C/SMBus bus access library
Group:		System/Libraries
License:	LGPLv2+

%description -n	%{libname}
libi2c offers a way for applications to interact with the devices
connected to the I2C or SMBus buses of the system.

#------------------------------------------------

%package -n	%{develname}
Summary:	Development package for the I2C library
Group:		Development/C++
License:	LGPLv2+
Requires:	%{libname} = %{version}-%{release}
Provides:	i2c-devel = %{version}-%{release}

%description -n	%{develname}
Header files for development for the I2C library.

#------------------------------------------------

%prep
%setup -q
%autopatch -p1

%build
%make_build CFLAGS="%{optflags}" LDFLAGS="%{ldflags}"

pushd py-smbus
%py3_build
popd

%install
%make_install PREFIX=%{_prefix} libdir=%{_libdir} BUILD_STATIC_LIB=0 EXTRA=eeprog

pushd py-smbus
%py3_install
popd

# for i2c-dev ondemand loading through kmod
mkdir -p %{buildroot}%{_modprobedir}
echo "alias char-major-89-* i2c-dev" > \
  %{buildroot}%{_modprobedir}/i2c-dev.conf
# for /dev/i2c-# creation (which are needed for kmod i2c-dev autoloading)
mkdir -p %{buildroot}%{_sysconfdir}/udev/makedev.d
for (( i = 0 ; i < 8 ; i++ )) do
  echo "i2c-$i" >> %{buildroot}%{_sysconfdir}/udev/makedev.d/99-i2c-dev.nodes
done

# auto-load i2c-dev after reboot
mkdir -p %{buildroot}%{_modulesloaddir}
echo 'i2c-dev' > %{buildroot}%{_modulesloaddir}/%{name}.conf

%post
# load i2c-dev after the first install
if [ "$1" = 1 ] ; then
    %{_sbindir}/modprobe i2c-dev
fi
exit 0

%files
%doc CHANGES COPYING README
%doc eeprog/README.eeprog
%config(noreplace) %{_modprobedir}/i2c-dev.conf
%config(noreplace) %{_sysconfdir}/udev/makedev.d/99-i2c-dev.nodes
%{_modulesloaddir}/%{name}.conf
%{_bindir}/ddcmon
%{_bindir}/decode-dimms
%{_bindir}/decode-edid
%{_bindir}/decode-vaio
%{_sbindir}/eeprog
%{_sbindir}/i2cdetect
%{_sbindir}/i2cdump
%{_sbindir}/i2cget
%{_sbindir}/i2cset
%{_sbindir}/i2ctransfer
%{_sbindir}/i2c-stub-from-dump
%{_mandir}/man1/decode-dimms.1*
%{_mandir}/man1/decode-vaio.1*
%{_mandir}/man8/eepro*.8*
%{_mandir}/man8/i2cdetect.8*
%{_mandir}/man8/i2cdump.8*
%{_mandir}/man8/i2cget.8*
%{_mandir}/man8/i2cset.8*
%{_mandir}/man8/i2ctransfer.8*
%{_mandir}/man8/i2c-stub-from-dump.8*

%files -n python3-smbus
%doc py-smbus/README
%{python3_sitearch}/smbus*

%files -n %{libname}
%license COPYING.LGPL
%{_libdir}/libi2c.so.%{major}{,.*}

%files -n %{develname}
%dir %{_includedir}/i2c
%{_includedir}/i2c/smbus.h
%{_libdir}/libi2c.so
%{_mandir}/man3/libi2c.3*


%changelog
* Wed Jul 02 2025 umeabot <umeabot> 4.4-3.mga10
+ Revision: 2242057
- Mageia 10 Mass Rebuild

* Mon Mar 03 2025 papoteur <papoteur> 4.4-2.mga10
+ Revision: 2159392
- Rebuild

* Mon Mar 03 2025 papoteur <papoteur> 4.4-1.mga10
+ Revision: 2159390
- new version 4.4

* Fri Dec 29 2023 daviddavid <daviddavid> 4.3-3.mga10
+ Revision: 2023637
- rebuild for py3.12

* Fri Dec 30 2022 daviddavid <daviddavid> 4.3-2.mga9
+ Revision: 1928077
- drop/obsolete eepromer subpackage, deprecated for 6 years
- move eeprog to i2c-tools (shouldn't have been in eepromer sub package)
- fix udev and modprobe servive (mga#31340)

* Thu Dec 29 2022 daviddavid <daviddavid> 4.3-1.mga9
+ Revision: 1927837
- new version: 4.3

* Sat Mar 19 2022 umeabot <umeabot> 4.2-3.mga9
+ Revision: 1799169
- Mageia 9 Mass Rebuild

* Thu Feb 17 2022 tv <tv> 4.2-2.mga9
+ Revision: 1778429
- Rebuild for python-3.10

* Thu Apr 01 2021 daviddavid <daviddavid> 4.2-1.mga9
+ Revision: 1712342
- new version: 4.2

* Fri Mar 26 2021 daviddavid <daviddavid> 4.1-5.mga9
+ Revision: 1710333
- rebuild for python 3.9

* Sun Feb 16 2020 umeabot <umeabot> 4.1-4.mga8
+ Revision: 1531323
- Mageia 8 Mass Rebuild

* Tue Sep 10 2019 wally <wally> 4.1-3.mga8
+ Revision: 1439431
- rebuild for python3.8
- drop python2 support

* Wed Jan 09 2019 daviddavid <daviddavid> 4.1-2.mga7
+ Revision: 1353060
- rebuild for new Python 3.7

* Sat Dec 01 2018 daviddavid <daviddavid> 4.1-1.mga7
+ Revision: 1337104
- new version: 4.1
- add the python3 module
- rename python-smbus to python2-smbus
- new lib and devel sub-pkg

* Sun Sep 23 2018 umeabot <umeabot> 3.1.2-3.mga7
+ Revision: 1298243
- Mageia 7 Mass Rebuild

* Thu Feb 11 2016 umeabot <umeabot> 3.1.2-2.mga6
+ Revision: 954337
- Mageia 6 Mass Rebuild

* Fri Aug 14 2015 sander85 <sander85> 3.1.2-1.mga6
+ Revision: 864722
- New version: 3.1.2

* Wed Oct 15 2014 umeabot <umeabot> 3.1.0-7.mga5
+ Revision: 745198
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 3.1.0-6.mga5
+ Revision: 726474
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 3.1.0-5.mga5
+ Revision: 680395
- Mageia 5 Mass Rebuild

* Sat May 31 2014 pterjan <pterjan> 3.1.0-4.mga5
+ Revision: 628257
- Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 3.1.0-3.mga4
+ Revision: 542670
- Mageia 4 Mass Rebuild

* Mon Oct 14 2013 pterjan <pterjan> 3.1.0-2.mga4
+ Revision: 497805
- Rebuild to add different pythonegg provides for python 2 and 3

* Fri Sep 27 2013 sander85 <sander85> 3.1.0-1.mga4
+ Revision: 487881
- New version: 3.1.0

* Sat Jan 12 2013 umeabot <umeabot> 3.0.3-2.mga3
+ Revision: 354016
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Apr 06 2011 tv <tv> 3.0.3-1.mga1
+ Revision: 81020
- imported package i2c-tools


* Wed Mar 16 2011 Stéphane Téletchéa <steletch@mandriva.org> 3.0.3-1mdv2011.0
+ Revision: 645236
- update to new version 3.0.3

* Tue Nov 02 2010 Jani Välimaa <wally@mandriva.org> 3.0.2-3mdv2011.0
+ Revision: 592187
- rebuild for python 2.7

* Fri Sep 11 2009 Thierry Vignaud <tv@mandriva.org> 3.0.2-2mdv2010.1
+ Revision: 437911
- rebuild

* Wed Feb 18 2009 Jérôme Soyer <saispo@mandriva.org> 3.0.2-1mdv2009.1
+ Revision: 342304
- New upstream release

* Fri Jan 02 2009 Funda Wang <fwang@mandriva.org> 3.0.1-6mdv2009.1
+ Revision: 323371
- rebuild

* Thu Nov 20 2008 Adam Williamson <awilliamson@mandriva.org> 3.0.1-5mdv2009.1
+ Revision: 305334
- fix the CFLAGS for the pysmbus build to include -I../include (right fix)
- drop pysmbus_include.patch (completely the wrong 'fix')

* Sun Nov 09 2008 Adam Williamson <awilliamson@mandriva.org> 3.0.1-4mdv2009.1
+ Revision: 301638
- requires python
- move kernel-headers BR into the python-smbus section for clarity
- python buildrequires
- add pysmbus_include.patch: add a necessary include for py-smbus to build
- build and package python-smbus too

* Fri Aug 29 2008 Olivier Blin <oblin@mandriva.com> 3.0.1-3mdv2009.0
+ Revision: 277375
- install udev helpers in /lib/udev (this is the default on x86_64 too now, as per upstream)

* Thu Aug 07 2008 Thierry Vignaud <tv@mandriva.org> 3.0.1-2mdv2009.0
+ Revision: 267108
- rebuild early 2009.0 package (before pixel changes)

* Sun Apr 20 2008 David Walluck <walluck@mandriva.org> 3.0.1-1mdv2009.0
+ Revision: 195989
- fix file list
- 3.0.1

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Tue Dec 11 2007 David Walluck <walluck@mandriva.org> 3.0.0-1mdv2008.1
+ Revision: 117438
- import i2c-tools


